# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/__init__.py


from __future__ import unicode_literals


__all__ = [
    "default_app_config",
]


default_app_config = "opensearch.apps.Config"
